@@ -11,11 +11,8 @@ use strict;
 use warnings;
 
 package App::Magpie::Action::Old::Module;
-{
-  $App::Magpie::Action::Old::Module::VERSION = '2.002';
-}
 # ABSTRACT: module that has a newer version available
-
+$App::Magpie::Action::Old::Module::VERSION = '2.003';
 use File::ShareDir::PathClass;
 use Moose;
 use MooseX::Has::Sugar;
@@ -103,6 +100,8 @@ sub category {
     return "strange" if scalar(@pkgs) >= 2;
     # scalar(@pkgs) == 1;
     return "ignored"    if exists $SKIPPKG{ $pkgs[0]->name };
+    return "confused"   if $self->oldver == $self->newver; # cpan can be confused
+    return "null"       if $self->oldver == 0 || $self->newver == 0;
     return "unparsable" if $self->oldver eq "Unparsable";
     return "normal";
 }
@@ -115,13 +114,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::Magpie::Action::Old::Module - module that has a newer version available
 
 =head1 VERSION
 
-version 2.002
+version 2.003
 
 =head1 DESCRIPTION
 
@@ -172,6 +173,10 @@ Return the module category:
 
 =item * C<strange> - shipped by more than one non-core package
 
+=item * C<confused> - when cpan reports a difference although there isn't
+
+=item * C<null> - when old or new versions are 0.0000
+
 =item * C<unparsable> - current version unparsable
 
 =back
